<?php

namespace Drupal\readmore_extrafield\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use \Drupal\Core\Url;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Example Extra field Display.
 *
 * @ExtraFieldDisplay(
 *   id = "readmore_extrafield",
 *   label = @Translation("Read more"),
 *   description = @Translation("Link to the entity"),
 *   bundles = {
 *     "node.*"
 *   },
 *   weight = 100
 * )
 */
class ReadMoreExtrafield extends ExtraFieldPlusDisplayFormattedBase
{
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity)
  {
    $settings = $this->getSettings();
    $title = $settings['title'];
    $elements[] = [
      '#theme' => 'readmore_extrafield',
      '#title' => $title,
      '#url' => Url::fromRoute('entity.node.canonical', [
        'node' => $entity
          ->id(),
      ]),
      '#attributes' => [
        'class' => [
          'readmore-extrafield-link'
        ]
      ]
    ];
    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    $form = parent::settingsForm();

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#description' => $this->t('The label of the read on hyperlink.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultFormValues() {
    $values = parent::defaultFormValues();

    $values += [
      'title' => $this->t('Read more'),
    ];

    return $values;
  }
}
